@@ -275,7 +275,7 @@ class PKPPublicationService implements EntityPropertyInterface, EntityReadInterf
 			[
 				'locale.regex' => __('validator.localeKey'),
 				'datePublished.date_format' => __('publication.datePublished.errorFormat'),
-				'urlPath.regex' => __('validator.alpha_dash'),
+				'urlPath.regex' => __('validator.alpha_dash_period'),
 			]
 		);
 
@@ -389,7 +389,7 @@ class PKPPublicationService implements EntityPropertyInterface, EntityReadInterf
 		}
 
 		// Don't allow a publication to be published before passing the review stage
-		if ($submission->getData('stageId') < WORKFLOW_STAGE_ID_EXTERNAL_REVIEW) {
+		if ($submission->getData('stageId') <= WORKFLOW_STAGE_ID_EXTERNAL_REVIEW) {
 			$errors['reviewStage'] = __('publication.required.reviewStage');
 		}
 
