@@ -7,12 +7,12 @@
 /**
  * @file pages/about/index.php
  *
- * Copyright (c) 2014-2016 Simon Fraser University Library
- * Copyright (c) 2003-2016 John Willinsky
- * Distributed under the GNU GPL v2. For full terms see the file docs/COPYING.
+ * Copyright (c) 2014-2021 Simon Fraser University
+ * Copyright (c) 2003-2021 John Willinsky
+ * Distributed under the GNU GPL v3. For full terms see the file docs/COPYING.
  *
  * @ingroup pages_about
- * @brief Handle requests for about the press functions.
+ * @brief Handle requests for about the context functions.
  *
  */
 
@@ -24,10 +24,11 @@ switch ($op) {
 		define('HANDLER_CLASS', 'AboutContextHandler');
 		import('lib.pkp.pages.about.AboutContextHandler');
 		break;
+	case 'privacy':
 	case 'aboutThisPublishingSystem':
 		define('HANDLER_CLASS', 'AboutSiteHandler');
 		import('lib.pkp.pages.about.AboutSiteHandler');
 		break;
 }
 
-?>
+
