@@ -49,6 +49,9 @@ abstract class PKPWorkflowHandler extends Handler {
 
 			$this->markRoleAssignmentsChecked();
 		} else {
+			import('lib.pkp.classes.security.authorization.internal.SubmissionCompletePolicy');
+			$this->addPolicy(new SubmissionCompletePolicy($request, $args, 'submissionId'));
+
 			import('lib.pkp.classes.security.authorization.WorkflowStageAccessPolicy');
 			$this->addPolicy(new WorkflowStageAccessPolicy($request, $args, $roleAssignments, 'submissionId', $this->identifyStageId($request, $args), WORKFLOW_TYPE_EDITORIAL));
 		}
@@ -77,7 +80,7 @@ abstract class PKPWorkflowHandler extends Handler {
 		// Get the closest workflow stage that user has an assignment.
 		$workingStageId = null;
 		for ($workingStageId = $currentStageId; $workingStageId >= WORKFLOW_STAGE_ID_SUBMISSION; $workingStageId--) {
-			if (isset($accessibleWorkflowStages[$workingStageId]) && array_intersect($editorialWorkflowRoles, $accessibleWorkflowStages[$workingStageId])) {
+			if (isset($accessibleWorkflowStages[$workingStageId]) && array_intersect($editorialWorkflowRoles, $accessibleWorkflowStages[$workingStageId] ?? [])) {
 				break;
 			}
 		}
@@ -86,7 +89,7 @@ abstract class PKPWorkflowHandler extends Handler {
 		// submission. Try to get the closest future workflow stage.
 		if ($workingStageId == null) {
 			for ($workingStageId = $currentStageId; $workingStageId <= WORKFLOW_STAGE_ID_PRODUCTION; $workingStageId++) {
-				if (isset($accessibleWorkflowStages[$workingStageId]) && array_intersect($editorialWorkflowRoles, $accessibleWorkflowStages[$workingStageId])) {
+				if (isset($accessibleWorkflowStages[$workingStageId]) && array_intersect($editorialWorkflowRoles, $accessibleWorkflowStages[$workingStageId] ?? [])) {
 					break;
 				}
 			}
@@ -147,14 +150,14 @@ abstract class PKPWorkflowHandler extends Handler {
 		$canPublish = false; // Ability to publish, unpublish and create versions
 		$canAccessEditorialHistory = false; // Access to activity log
 		// unassigned managers
-		if (!$accessibleWorkflowStages && array_intersect($this->getAuthorizedContextObject(ASSOC_TYPE_USER_ROLES), [ROLE_ID_MANAGER])) {
+		if (!$accessibleWorkflowStages && array_intersect($this->getAuthorizedContextObject(ASSOC_TYPE_USER_ROLES), [ROLE_ID_MANAGER] ?? [])) {
 			$canAccessProduction = true;
 			$canPublish = true;
 			$canAccessPublication = true;
 			$canAccessEditorialHistory = true;
 
-		} elseif (!empty($accessibleWorkflowStages[$currentStageId]) && array_intersect($editorialWorkflowRoles, $accessibleWorkflowStages[$currentStageId])) {
-			$canAccessProduction = (bool) array_intersect($editorialWorkflowRoles, $accessibleWorkflowStages[WORKFLOW_STAGE_ID_PRODUCTION]);
+		} elseif (!empty($accessibleWorkflowStages[$currentStageId]) && array_intersect($editorialWorkflowRoles, $accessibleWorkflowStages[$currentStageId] ?? [])) {
+			$canAccessProduction = (bool) array_intersect($editorialWorkflowRoles, $accessibleWorkflowStages[WORKFLOW_STAGE_ID_PRODUCTION] ?? []);
 			$canAccessPublication = true;
 
 			$stageAssignmentDao = DAORegistry::getDAO('StageAssignmentDAO'); /* @var $stageAssignmentDao StageAssignmentDAO */
@@ -168,7 +171,7 @@ abstract class PKPWorkflowHandler extends Handler {
 			// for the production workflow stage. An unassigned admin or manager may
 			// have been granted access and should be allowed to publish.
 			if (empty($result) && is_array($accessibleWorkflowStages[WORKFLOW_STAGE_ID_PRODUCTION])) {
-				$canPublish = (bool) array_intersect([ROLE_ID_SITE_ADMIN, ROLE_ID_MANAGER], $accessibleWorkflowStages[WORKFLOW_STAGE_ID_PRODUCTION]);
+				$canPublish = (bool) array_intersect([ROLE_ID_SITE_ADMIN, ROLE_ID_MANAGER], $accessibleWorkflowStages[WORKFLOW_STAGE_ID_PRODUCTION] ?? []);
 
 			// Otherwise, check stage assignments
 			// "Recommend only" stage assignments can not publish
@@ -184,7 +187,7 @@ abstract class PKPWorkflowHandler extends Handler {
 				}
 			}
 		}
-		if (!empty($accessibleWorkflowStages[$currentStageId]) && array_intersect([ROLE_ID_MANAGER, ROLE_ID_SUB_EDITOR], $accessibleWorkflowStages[$currentStageId])) {
+		if (!empty($accessibleWorkflowStages[$currentStageId]) && array_intersect([ROLE_ID_MANAGER, ROLE_ID_SUB_EDITOR], $accessibleWorkflowStages[$currentStageId] ?? [])) {
 			$canAccessEditorialHistory = true;
 		}
 
@@ -357,19 +360,15 @@ abstract class PKPWorkflowHandler extends Handler {
 		];
 
 		// Add the metadata form if one or more metadata fields are enabled
-		$metadataFields = ['coverage', 'disciplines', 'keywords', 'languages', 'rights', 'source', 'subjects', 'agencies', 'type'];
-		$metadataEnabled = false;
-		foreach ($metadataFields as $metadataField) {
-			if ($submissionContext->getData($metadataField)) {
-				$metadataEnabled = true;
-				break;
-			}
-		}
-		if ($metadataEnabled || in_array('publication', (array) $submissionContext->getData('enablePublisherId'))) {
-			$vocabSuggestionUrlBase =$request->getDispatcher()->url($request, ROUTE_API, $submissionContext->getData('urlPath'), 'vocabs', null, null, ['vocab' => '__vocab__']);
-			$metadataForm = new PKP\components\forms\publication\PKPMetadataForm($latestPublicationApiUrl, $locales, $latestPublication, $submissionContext, $vocabSuggestionUrlBase);
+		$vocabSuggestionUrlBase =$request->getDispatcher()->url($request, ROUTE_API, $submissionContext->getData('urlPath'), 'vocabs', null, null, ['vocab' => '__vocab__']);
+		$metadataForm = new PKP\components\forms\publication\PKPMetadataForm($latestPublicationApiUrl, $locales, $latestPublication, $submissionContext, $vocabSuggestionUrlBase);
+		$metadataFormConfig = $metadataForm->getConfig();
+
+		$metadataEnabled = !empty($metadataFormConfig['fields']);
+		
+		if ($metadataEnabled) {
 			$templateMgr->setConstants(['FORM_METADATA']);
-			$state['components'][FORM_METADATA] = $metadataForm->getConfig();
+			$state['components'][FORM_METADATA] = $metadataFormConfig;
 			$state['publicationFormIds'][] = FORM_METADATA;
 		}
 
