@@ -3,19 +3,44 @@
 /**
  * @file pages/gateway/GatewayHandler.inc.php
  *
- * Copyright (c) 2014-2019 Simon Fraser University
- * Copyright (c) 2003-2019 John Willinsky
- * Distributed under the GNU GPL v2. For full terms see the file docs/COPYING.
+ * Copyright (c) 2014-2021 Simon Fraser University
+ * Copyright (c) 2003-2021 John Willinsky
+ * Distributed under the GNU GPL v3. For full terms see the file docs/COPYING.
  *
  * @class GatewayHandler
  * @ingroup pages_gateway
  *
- * @brief Handle external gateway requests. 
+ * @brief Handle external gateway requests.
  */
 
 import('classes.handler.Handler');
 
 class GatewayHandler extends Handler {
+
+	var $plugin;
+
+	/**
+	 * Constructor
+	 *
+	 * @param $request PKPRequest
+	 */
+	function __construct($request) {
+		parent::__construct();
+		$op = $request->getRouter()->getRequestedOp($request);
+		if ($op == 'plugin') {
+			$args = $request->getRouter()->getRequestedArgs($request);
+			$pluginName = array_shift($args);
+			$plugins = PluginRegistry::loadCategory('gateways');
+			if (!isset($plugins[$pluginName])) {
+				$request->getDispatcher()->handle404();
+			}
+			$this->plugin = $plugins[$pluginName];
+			foreach ($this->plugin->getPolicies($request) as $policy) {
+				$this->addPolicy($policy);
+			}
+		}
+	}
+
 	/**
 	 * Index handler.
 	 * @param $args array
@@ -38,58 +63,59 @@ class GatewayHandler extends Handler {
 		$templateMgr = TemplateManager::getManager($request);
 
 		if ($journal != null) {
-			if (!$journal->getSetting('enableLockss')) {
+			if (!$journal->getData('enableLockss')) {
 				$request->redirect(null, 'index');
 			}
 
 			$year = $request->getUserVar('year');
 
-			$issueDao = DAORegistry::getDAO('IssueDAO');
+			$issueDao = DAORegistry::getDAO('IssueDAO'); /* @var $issueDao IssueDAO */
 
 			// FIXME Should probably go in IssueDAO or a subclass
 			if (isset($year)) {
 				$year = (int)$year;
 				$result = $issueDao->retrieve(
 					'SELECT * FROM issues WHERE journal_id = ? AND year = ? AND published = 1 ORDER BY current DESC, year ASC, volume ASC, number ASC',
-					array($journal->getId(), $year)
+					[$journal->getId(), $year]
 				);
-				if ($result->RecordCount() == 0) {
-					unset($year);
-				}
+				if (!$result->current()) unset($year);
 			}
 
 			if (!isset($year)) {
 				$result = $issueDao->retrieve(
-					'SELECT MAX(year) FROM issues WHERE journal_id = ? AND published = 1',
-					$journal->getId()
+					'SELECT MAX(year) AS max_year FROM issues WHERE journal_id = ? AND published = 1',
+					[$journal->getId()]
 				);
-				list($year) = $result->fields;
+				$row = $result->current();
+				$year = $row?$row->max_year:null;
 				$templateMgr->assign('showInfo', true);
 			}
 
 			$prevYear = $nextYear = null;
 			if (isset($year)) {
 				$result = $issueDao->retrieve(
-					'SELECT MAX(year) FROM issues WHERE journal_id = ? AND published = 1 AND year < ?',
-					array($journal->getId(), $year)
+					'SELECT MAX(year) AS max_year FROM issues WHERE journal_id = ? AND published = 1 AND year < ?',
+					[$journal->getId(), $year]
 				);
-				list($prevYear) = $result->fields;
+				$row = $result->current();
+				$prevYear = $row?$row->max_year:null;
 
 				$result = $issueDao->retrieve(
-					'SELECT MIN(year) FROM issues WHERE journal_id = ? AND published = 1 AND year > ?',
-					array($journal->getId(), $year)
+					'SELECT MIN(year) AS min_year FROM issues WHERE journal_id = ? AND published = 1 AND year > ?',
+					[$journal->getId(), $year]
 				);
-				list($nextYear) = $result->fields;
+				$row = $result->current();
+				$nextYear = $row?$row->min_year:null;
 			}
 
 			$issues = $issueDao->getPublishedIssuesByNumber($journal->getId(), null, null, $year);
-			$templateMgr->assign(array(
+			$templateMgr->assign([
 				'journal' => $journal,
 				'year' => $year,
 				'prevYear' => $prevYear,
 				'nextYear' => $nextYear,
 				'issues' => $issues,
-			));
+			]);
 
 			$locales = $journal->getSupportedLocaleNames();
 			if (!isset($locales) || empty($locales)) {
@@ -99,7 +125,7 @@ class GatewayHandler extends Handler {
 			}
 			$templateMgr->assign('locales', $locales);
 		} else {
-			$journalDao = DAORegistry::getDAO('JournalDAO');
+			$journalDao = DAORegistry::getDAO('JournalDAO'); /* @var $journalDao JournalDAO */
 			$journals = $journalDao->getAll(true);
 			$templateMgr->assign('journals', $journals);
 		}
@@ -120,62 +146,64 @@ class GatewayHandler extends Handler {
 		$templateMgr = TemplateManager::getManager($request);
 
 		if ($journal != null) {
-			if (!$journal->getSetting('enableClockss')) {
+			if (!$journal->getData('enableClockss')) {
 				$request->redirect(null, 'index');
 			}
 
 			$year = $request->getUserVar('year');
 
-			$issueDao = DAORegistry::getDAO('IssueDAO');
+			$issueDao = DAORegistry::getDAO('IssueDAO'); /* @var $issueDao IssueDAO */
 
 			// FIXME Should probably go in IssueDAO or a subclass
 			if (isset($year)) {
 				$year = (int)$year;
 				$result = $issueDao->retrieve(
 					'SELECT * FROM issues WHERE journal_id = ? AND year = ? AND published = 1 ORDER BY current DESC, year ASC, volume ASC, number ASC',
-					array($journal->getId(), $year)
+					[$journal->getId(), $year]
 				);
-				if ($result->RecordCount() == 0) {
-					unset($year);
-				}
+				$row = $result->current();
+				if (!$row) unset($year);
 			}
 
 			if (!isset($year)) {
 				$result = $issueDao->retrieve(
-					'SELECT MAX(year) FROM issues WHERE journal_id = ? AND published = 1',
-					$journal->getId()
+					'SELECT MAX(year) AS max_year FROM issues WHERE journal_id = ? AND published = 1',
+					[$journal->getId()]
 				);
-				list($year) = $result->fields;
+				$row = $result->current();
+				$year = $row?$row->max_year:null;
 				$issues = $issueDao->getPublishedIssuesByNumber($journal->getId(), null, null, $year);
-				$templateMgr->assign(array(
+				$templateMgr->assign([
 					'issues' => $issues,
 					'showInfo' => true,
-				));
+				]);
 			}
 
 			$prevYear = $nextYear = null;
 			if (isset($year)) {
 				$result = $issueDao->retrieve(
-					'SELECT MAX(year) FROM issues WHERE journal_id = ? AND published = 1 AND year < ?',
-					array($journal->getId(), $year)
+					'SELECT MAX(year) AS max_year FROM issues WHERE journal_id = ? AND published = 1 AND year < ?',
+					[$journal->getId(), $year]
 				);
-				list($prevYear) = $result->fields;
+				$row = $result->current();
+				$prevYear = $row?$row->max_year:null;
 
 				$result = $issueDao->retrieve(
-					'SELECT MIN(year) FROM issues WHERE journal_id = ? AND published = 1 AND year > ?',
-					array($journal->getId(), $year)
+					'SELECT MIN(year) AS min_year FROM issues WHERE journal_id = ? AND published = 1 AND year > ?',
+					[$journal->getId(), $year]
 				);
-				list($nextYear) = $result->fields;
+				$row = $result->current();
+				$nextYear = $row?$row->min_year:null;
 			}
 
 			$issues = $issueDao->getPublishedIssuesByNumber($journal->getId(), null, null, $year);
-			$templateMgr->assign(array(
+			$templateMgr->assign([
 				'journal' => $journal,
 				'year' => $year,
 				'prevYear' => $prevYear,
 				'nextYear' => $nextYear,
 				'issues' => $issues,
-			));
+			]);
 
 			$locales = $journal->getSupportedLocaleNames();
 			if (!isset($locales) || empty($locales)) {
@@ -186,7 +214,7 @@ class GatewayHandler extends Handler {
 			$templateMgr->assign('locales', $locales);
 
 		} else {
-			$journalDao = DAORegistry::getDAO('JournalDAO');
+			$journalDao = DAORegistry::getDAO('JournalDAO'); /* @var $journalDao JournalDAO */
 			$journals = $journalDao->getAll(true);
 			$templateMgr->assign('journals', $journals);
 		}
@@ -201,12 +229,8 @@ class GatewayHandler extends Handler {
 	 */
 	function plugin($args, $request) {
 		$this->validate();
-		$pluginName = array_shift($args);
-
-		$plugins = PluginRegistry::loadCategory('gateways');
-		if (isset($pluginName) && isset($plugins[$pluginName])) {
-			$plugin = $plugins[$pluginName];
-			if (!$plugin->fetch($args, $request)) {
+		if (isset($this->plugin)) {
+			if (!$this->plugin->fetch(array_slice($args, 1), $request)) {
 				$request->redirect(null, 'index');
 			}
 		} else {
@@ -214,4 +238,3 @@ class GatewayHandler extends Handler {
 		}
 	}
 }
-
