@@ -3,9 +3,9 @@
 /**
  * @file pages/issue/IssueHandler.inc.php
  *
- * Copyright (c) 2014-2016 Simon Fraser University Library
- * Copyright (c) 2003-2016 John Willinsky
- * Distributed under the GNU GPL v2. For full terms see the file docs/COPYING.
+ * Copyright (c) 2014-2021 Simon Fraser University
+ * Copyright (c) 2003-2021 John Willinsky
+ * Distributed under the GNU GPL v3. For full terms see the file docs/COPYING.
  *
  * @class IssueHandler
  * @ingroup pages_issue
@@ -20,12 +20,6 @@ class IssueHandler extends Handler {
 	/** @var IssueGalley retrieved issue galley */
 	var $_galley = null;
 
-	/**
-	 * Constructor
-	 **/
-	function IssueHandler() {
-		parent::Handler();
-	}
 
 	/**
 	 * @copydoc PKPHandler::authorize()
@@ -46,13 +40,14 @@ class IssueHandler extends Handler {
 
 	/**
 	 * @see PKPHandler::initialize()
+	 * @param $args array Arguments list
 	 */
-	function initialize($request, $args) {
+	function initialize($request, $args = array()) {
 		// Get the issue galley
-		$galleyId = isset($args[1]) && is_numeric($args[1]) ? $args[1] : 0;
+		$galleyId = isset($args[1]) ? $args[1] : 0;
 		if ($galleyId) {
 			$issue = $this->getAuthorizedContextObject(ASSOC_TYPE_ISSUE);
-			$galleyDao = DAORegistry::getDAO('IssueGalleyDAO');
+			$galleyDao = DAORegistry::getDAO('IssueGalleyDAO'); /* @var $galleyDao IssueGalleyDAO */
 			$journal = $request->getJournal();
 			$galley = $galleyDao->getByBestId($galleyId, $issue->getId());
 
@@ -74,19 +69,16 @@ class IssueHandler extends Handler {
 	 * Display current issue page.
 	 */
 	function current($args, $request) {
-		$this->setupTemplate($request);
-
 		$journal = $request->getJournal();
-
-		$issueDao = DAORegistry::getDAO('IssueDAO');
+		$issueDao = DAORegistry::getDAO('IssueDAO'); /* @var $issueDao IssueDAO */
 		$issue = $issueDao->getCurrent($journal->getId(), true);
 
-		$templateMgr = TemplateManager::getManager($request);
-
 		if ($issue != null) {
-			$request->redirect(null, 'issue', 'view', $issue->getId(), $request->getQueryArray());
+			$request->redirect(null, 'issue', 'view', $issue->getBestIssueId());
 		}
 
+		$this->setupTemplate($request);
+		$templateMgr = TemplateManager::getManager($request);
 		// consider public identifiers
 		$pubIdPlugins = PluginRegistry::loadCategory('pubIds', true);
 		$templateMgr->assign('pubIdPlugins', $pubIdPlugins);
@@ -104,12 +96,12 @@ class IssueHandler extends Handler {
 		$templateMgr = TemplateManager::getManager($request);
 		$journal = $request->getJournal();
 
-		if ($galley = $this->getGalley()) {
+		if (($galley = $this->getGalley()) && $this->userCanViewGalley($request)) {
 			if (!HookRegistry::call('IssueHandler::view::galley', array(&$request, &$issue, &$galley))) {
 				$request->redirect(null, null, 'download', array($issue->getBestIssueId($journal), $galley->getBestGalleyId($journal)));
 			}
 		} else {
-			$this->_setupIssueTemplate($request, $issue, $request->getUserVar('showToc') ? true : false);
+			self::_setupIssueTemplate($request, $issue, $request->getUserVar('showToc') ? true : false);
 			$templateMgr->assign('issueId', $issue->getBestIssueId());
 
 			// consider public identifiers
@@ -126,19 +118,42 @@ class IssueHandler extends Handler {
 	 */
 	function archive($args, $request) {
 		$this->setupTemplate($request);
-		$journal = $request->getJournal();
-
+		$page = isset($args[0]) ? (int) $args[0] : 1;
 		$templateMgr = TemplateManager::getManager($request);
-		import('classes.file.PublicFileManager');
-		$publicFileManager = new PublicFileManager();
-		$coverImagePath = $request->getBaseUrl() . '/';
-		$coverImagePath .= $publicFileManager->getJournalFilesPath($journal->getId()) . '/';
-		$templateMgr->assign('coverImagePath', $coverImagePath);
+		$context = $request->getContext();
+
+		$count = $context->getData('itemsPerPage') ? $context->getData('itemsPerPage') : Config::getVar('interface', 'items_per_page');
+		$offset = $page > 1 ? ($page - 1) * $count : 0;
+
+		$params = array(
+			'contextId' => $context->getId(),
+			'orderBy' => 'seq',
+			'orderDirection' => 'ASC',
+			'count' => $count,
+			'offset' => $offset,
+			'isPublished' => true,
+		);
+		$issues = iterator_to_array(Services::get('issue')->getMany($params));
+		$total = Services::get('issue')->getMax($params);
+
+		$showingStart = $offset + 1;
+		$showingEnd = min($offset + $count, $offset + count($issues));
+		$nextPage = $total > $showingEnd ? $page + 1 : null;
+		$prevPage = $showingStart > 1 ? $page - 1 : null;
+
+		if (!count($issues) && $offset) {
+			$this->getDispatcher()->handle404();
+		}
+
+		$templateMgr->assign(array(
+			'issues' => $issues,
+			'showingStart' => $showingStart,
+			'showingEnd' => $showingEnd,
+			'total' => $total,
+			'nextPage' => $nextPage,
+			'prevPage' => $prevPage,
+		));
 
-		$rangeInfo = $this->getRangeInfo($request, 'issues');
-		$issueDao = DAORegistry::getDAO('IssueDAO');
-		$publishedIssuesIterator = $issueDao->getPublishedIssues($journal->getId(), $rangeInfo);
-		$templateMgr->assign('issues', $publishedIssuesIterator);
 		$templateMgr->display('frontend/pages/issueArchive.tpl');
 	}
 
@@ -155,7 +170,7 @@ class IssueHandler extends Handler {
 			if (!HookRegistry::call('IssueHandler::download', array(&$issue, &$galley))) {
 				import('classes.file.IssueFileManager');
 				$issueFileManager = new IssueFileManager($issue->getId());
-				return $issueFileManager->downloadFile($galley->getFileId(), $request->getUserVar('inline')?true:false);
+				return $issueFileManager->downloadById($galley->getFileId(), $request->getUserVar('inline')?true:false);
 			}
 		}
 	}
@@ -193,29 +208,26 @@ class IssueHandler extends Handler {
 
 		// If this is an editorial user who can view unpublished issue galleys,
 		// bypass further validation
-		if ($issueAction->allowedIssuePrePublicationAccess($journal)) return true;
+		if ($issueAction->allowedIssuePrePublicationAccess($journal, $user)) return true;
 
 		// Ensure reader has rights to view the issue galley
 		if ($issue->getPublished()) {
-			$subscriptionRequired = $issueAction->subscriptionRequired($issue);
-			$isSubscribedDomain = $issueAction->subscribedDomain($journal, $issue->getId());
+			$subscriptionRequired = $issueAction->subscriptionRequired($issue, $journal);
+			$isSubscribedDomain = $issueAction->subscribedDomain($request, $journal, $issue->getId());
 
 			// Check if login is required for viewing.
-			if (!$isSubscribedDomain && !Validation::isLoggedIn() && $journal->getSetting('restrictArticleAccess')) {
+			if (!$isSubscribedDomain && !Validation::isLoggedIn() && $journal->getData('restrictArticleAccess')) {
 				Validation::redirectLogin();
 			}
 
 			// If no domain/ip subscription, check if user has a valid subscription
 			// or if the user has previously purchased the issue
 			if (!$isSubscribedDomain && $subscriptionRequired) {
-
 				// Check if user has a valid subscription
-				$subscribedUser = $issueAction->subscribedUser($journal, $issue->getId());
-
+				$subscribedUser = $issueAction->subscribedUser($user, $journal, $issue->getId());
 				if (!$subscribedUser) {
 					// Check if payments are enabled,
-					import('classes.payment.ojs.OJSPaymentManager');
-					$paymentManager = new OJSPaymentManager($request);
+					$paymentManager = Application::getPaymentManager($journal);
 
 					if ($paymentManager->purchaseIssueEnabled() || $paymentManager->membershipEnabled() ) {
 						// If only pdf files are being restricted, then approve all non-pdf galleys
@@ -227,16 +239,17 @@ class IssueHandler extends Handler {
 						}
 
 						// If the issue galley has been purchased, then allow reader access
-						$completedPaymentDao = DAORegistry::getDAO('OJSCompletedPaymentDAO');
+						$completedPaymentDao = DAORegistry::getDAO('OJSCompletedPaymentDAO'); /* @var $completedPaymentDao OJSCompletedPaymentDAO */
 						$dateEndMembership = $user->getSetting('dateEndMembership', 0);
 						if ($completedPaymentDao->hasPaidPurchaseIssue($userId, $issue->getId()) || (!is_null($dateEndMembership) && $dateEndMembership > time())) {
 							return true;
 						} else {
 							// Otherwise queue an issue purchase payment and display payment form
-							$queuedPayment =& $paymentManager->createQueuedPayment($journal->getId(), PAYMENT_TYPE_PURCHASE_ISSUE, $userId, $issue->getId(), $journal->getSetting('purchaseIssueFee'));
-							$queuedPaymentId = $paymentManager->queuePayment($queuedPayment);
+							$queuedPayment = $paymentManager->createQueuedPayment($request, PAYMENT_TYPE_PURCHASE_ISSUE, $userId, $issue->getId(), $journal->getData('purchaseIssueFee'));
+							$paymentManager->queuePayment($queuedPayment);
 
-							$paymentManager->displayPaymentForm($queuedPaymentId, $queuedPayment);
+							$paymentForm = $paymentManager->getPaymentForm($queuedPayment);
+							$paymentForm->display($request);
 							exit;
 						}
 					}
@@ -267,17 +280,14 @@ class IssueHandler extends Handler {
 	 * 	the cover page will be displayed. Otherwise table of contents
 	 * 	will be displayed.
 	 */
-	function _setupIssueTemplate($request, $issue, $showToc = false) {
+	static function _setupIssueTemplate($request, $issue, $showToc = false) {
 		$journal = $request->getJournal();
+		$user = $request->getUser();
 		$templateMgr = TemplateManager::getManager($request);
 
 		// Determine pre-publication access
 		// FIXME: Do that. (Bug #8278)
 
-		if (!$issue) {
-			$issue = $this->getAuthorizedContextObject(ASSOC_TYPE_ISSUE);
-		}
-
 		$templateMgr->assign(array(
 			'issueIdentification' => $issue->getIssueIdentification(),
 			'issueTitle' => $issue->getLocalizedTitle(),
@@ -286,56 +296,91 @@ class IssueHandler extends Handler {
 
 		$locale = AppLocale::getLocale();
 
-		import('classes.file.PublicFileManager');
-		$publicFileManager = new PublicFileManager();
 		$templateMgr->assign(array(
-			'coverImagePath' => $request->getBaseUrl() . '/' . $publicFileManager->getJournalFilesPath($journal->getId()) . '/',
 			'locale' => $locale,
 		));
 
-		$issueGalleyDao = DAORegistry::getDAO('IssueGalleyDAO');
-		$publishedArticleDao = DAORegistry::getDAO('PublishedArticleDAO');
+		$issueGalleyDao = DAORegistry::getDAO('IssueGalleyDAO'); /* @var $issueGalleyDao IssueGalleyDAO */
+
+		$genreDao = DAORegistry::getDAO('GenreDAO'); /* @var $genreDao GenreDAO */
+		$primaryGenres = $genreDao->getPrimaryByContextId($journal->getId())->toArray();
+		$primaryGenreIds = array_map(function($genre) {
+			return $genre->getId();
+		}, $primaryGenres);
+
+		// Show scheduled submissions if this is a preview
+		import('classes.submission.Submission'); // import STATUS_ constants
+		$allowedStatuses = [STATUS_PUBLISHED];
+		if (!$issue->getPublished()) {
+			$allowedStatuses[] = STATUS_SCHEDULED;
+		}
+
+		$issueSubmissions = iterator_to_array(Services::get('submission')->getMany([
+			'contextId' => $journal->getId(),
+			'issueIds' => [$issue->getId()],
+			'status' => $allowedStatuses,
+			'orderBy' => 'seq',
+			'orderDirection' => 'ASC',
+		]));
+
+		$sections = Application::get()->getSectionDao()->getByIssueId($issue->getId());
+		$issueSubmissionsInSection = [];
+		foreach ($sections as $section) {
+			$issueSubmissionsInSection[$section->getId()] = [
+				'title' => $section->getHideTitle()?null:$section->getLocalizedTitle(),
+				'hideAuthor' => $section->getHideAuthor(),
+				'articles' => [],
+			];
+		}
+		foreach ($issueSubmissions as $submission) {
+			if (!$sectionId = $submission->getCurrentPublication()->getData('sectionId')) {
+				continue;
+			}
+			$issueSubmissionsInSection[$sectionId]['articles'][] = $submission;
+		}
 
 		$templateMgr->assign(array(
 			'issue' => $issue,
 			'issueGalleys' => $issueGalleyDao->getByIssueId($issue->getId()),
-			'publishedArticles' => $publishedArticleDao->getPublishedArticlesInSections($issue->getId(), true),
+			'publishedSubmissions' => $issueSubmissionsInSection,
+			'primaryGenreIds' => $primaryGenreIds,
 		));
 
 		// Subscription Access
 		import('classes.issue.IssueAction');
 		$issueAction = new IssueAction();
-		$subscriptionRequired = $issueAction->subscriptionRequired($issue);
-		$subscribedUser = $issueAction->subscribedUser($journal);
-		$subscribedDomain = $issueAction->subscribedDomain($journal);
+		$subscriptionRequired = $issueAction->subscriptionRequired($issue, $journal);
+		$subscribedUser = $issueAction->subscribedUser($user, $journal);
+		$subscribedDomain = $issueAction->subscribedDomain($request, $journal);
 
 		if ($subscriptionRequired && !$subscribedUser && !$subscribedDomain) {
 			$templateMgr->assign('subscriptionExpiryPartial', true);
 
 			// Partial subscription expiry for issue
-			$partial = $issueAction->subscribedUser($journal, $issue->getId());
-			if (!$partial) $issueAction->subscribedDomain($journal, $issue->getId());
+			$partial = $issueAction->subscribedUser($user, $journal, $issue->getId());
+			if (!$partial) $issueAction->subscribedDomain($request, $journal, $issue->getId());
 			$templateMgr->assign('issueExpiryPartial', $partial);
 
 			// Partial subscription expiry for articles
-			$publishedArticleDao = DAORegistry::getDAO('PublishedArticleDAO');
-			$publishedArticlesTemp =& $publishedArticleDao->getPublishedArticles($issue->getId());
-
 			$articleExpiryPartial = array();
-			foreach ($publishedArticlesTemp as $publishedArticle) {
-				$partial = $issueAction->subscribedUser($journal, $issue->getId(), $publishedArticle->getId());
-				if (!$partial) $issueAction->subscribedDomain($journal, $issue->getId(), $publishedArticle->getId());
-				$articleExpiryPartial[$publishedArticle->getId()] = $partial;
+			foreach ($issueSubmissions as $issueSubmission) {
+				$partial = $issueAction->subscribedUser($user, $journal, $issue->getId(), $issueSubmission->getId());
+				if (!$partial) $issueAction->subscribedDomain($request, $journal, $issue->getId(), $issueSubmission->getId());
+				$articleExpiryPartial[$issueSubmission->getId()] = $partial;
 			}
 			$templateMgr->assign('articleExpiryPartial', $articleExpiryPartial);
 		}
 
+		$completedPaymentDao = DAORegistry::getDAO('OJSCompletedPaymentDAO'); /* @var $completedPaymentDao OJSCompletedPaymentDAO */
 		$templateMgr->assign(array(
-			'hasAccess' => !$subscriptionRequired || $issue->getAccessStatus() == ISSUE_ACCESS_OPEN || $subscribedUser || $subscribedDomain
+			'hasAccess' => !$subscriptionRequired ||
+				$issue->getAccessStatus() == ISSUE_ACCESS_OPEN ||
+				$subscribedUser || $subscribedDomain ||
+				($user && $completedPaymentDao->hasPaidPurchaseIssue($user->getId(), $issue->getId()))
 		));
 
 		import('classes.payment.ojs.OJSPaymentManager');
-		$paymentManager = new OJSPaymentManager($request);
+		$paymentManager = Application::getPaymentManager($journal);
 		if ( $paymentManager->onlyPdfEnabled() ) {
 			$templateMgr->assign('restrictOnlyPdf', true);
 		}
@@ -344,5 +389,3 @@ class IssueHandler extends Handler {
 		}
 	}
 }
-
-?>
