@@ -3,9 +3,9 @@
 /**
  * @file OrcidProfilePlugin.inc.php
  *
- * Copyright (c) 2015-2019 University of Pittsburgh
- * Copyright (c) 2014-2021 Simon Fraser University
- * Copyright (c) 2003-2021 John Willinsky
+ * Copyright (c) 2015-2022 University of Pittsburgh
+ * Copyright (c) 2014-2022 Simon Fraser University
+ * Copyright (c) 2003-2022 John Willinsky
  * Distributed under the GNU GPL v3. For full terms see the file docs/COPYING.
  *
  * @class OrcidProfilePlugin
@@ -96,48 +96,50 @@ class OrcidProfilePlugin extends GenericPlugin {
 
 		HookRegistry::register('ThankReviewerForm::thankReviewer', array($this, 'handleThankReviewer'));
 
+		HookRegistry::register('Publication::validatePublish', [$this, 'validate']);
+
 		// Add more ORCiD fields to author Schema
 		HookRegistry::register('Schema::get::author', function ($hookName, $args) {
 			$schema = $args[0];
 
 			$schema->properties->orcidSandbox = (object)[
 				'type' => 'string',
-				'apiSummary' => true,
+				'writeOnly' => 'true',
 				'validation' => ['nullable']
 			];
 			$schema->properties->orcidAccessToken = (object)[
 				'type' => 'string',
-				'apiSummary' => true,
+				'writeOnly' => 'true',
 				'validation' => ['nullable']
 			];
 			$schema->properties->orcidAccessScope = (object)[
 				'type' => 'string',
-				'apiSummary' => true,
+				'writeOnly' => 'true',
 				'validation' => ['nullable']
 			];
 			$schema->properties->orcidRefreshToken = (object)[
 				'type' => 'string',
-				'apiSummary' => true,
+				'writeOnly' => 'true',
 				'validation' => ['nullable']
 			];
 			$schema->properties->orcidAccessExpiresOn = (object)[
 				'type' => 'string',
-				'apiSummary' => true,
+				'writeOnly' => 'true',
 				'validation' => ['nullable']
 			];
 			$schema->properties->orcidAccessDenied = (object)[
 				'type' => 'string',
-				'apiSummary' => true,
+				'writeOnly' => 'true',
 				'validation' => ['nullable']
 			];
 			$schema->properties->orcidEmailToken = (object)[
 				'type' => 'string',
-				'apiSummary' => true,
+				'writeOnly' => 'true',
 				'validation' => ['nullable']
 			];
 			$schema->properties->orcidWorkPutCode = (object)[
 				'type' => 'string',
-				'apiSummary' => true,
+				'writeOnly' => 'true',
 				'validation' => ['nullable']
 			];
 		});
@@ -152,8 +154,10 @@ class OrcidProfilePlugin extends GenericPlugin {
 		$request = PKPApplication::get()->getRequest();
 		$context = $request->getContext();
 		$newPublication =& $args[0];
-		if ($this->getSetting($context->getId(), 'country') && $this->getSetting($context->getId(), 'city')) {
-			$this->publishReviewerWorkToOrcid($newPublication, $request);
+		if ($this->isMemberApiEnabled($this->currentContextId)) {
+			if ($this->getSetting($context->getId(), 'country') && $this->getSetting($context->getId(), 'city')) {
+				$this->publishReviewerWorkToOrcid($newPublication, $request);
+			}
 		}
 	}
 
@@ -186,25 +190,34 @@ class OrcidProfilePlugin extends GenericPlugin {
 				return parent::getSetting($contextId, $name);
 		}
 
-		return $config_value ?: parent::getSetting($contextId, $name);
-	}
-
-
-	/**
-	 * Hook callback: register pages for each sushi-lite method
-	 * This URL is of the form: orcidapi/{$orcidrequest}
-	 * @see PKPPageRouter::route()
-	 */
-	function setupCallbackHandler($hookName, $params) {
-		$page = $params[0];
-		if ($this->getEnabled() && $page == 'orcidapi') {
-			$this->import('pages/OrcidHandler');
-			define('HANDLER_CLASS', 'OrcidHandler');
-			return true;
+		$config_value = $config_value ?? parent::getSetting($contextId, $name);
+		if ($name == 'orcidProfileAPIPath') {
+			if ($config_value == 'https://orcid.org/') {
+				$config_value = ORCID_API_URL_PUBLIC;
+			} elseif ($config_value == 'https://sandbox.orcid.org/') {
+				$config_value = ORCID_API_URL_PUBLIC_SANDBOX;
+			}
 		}
-		return false;
+		return $config_value;
 	}
 
+    /**
+     * Hook callback: register pages for each sushi-lite method
+     * This URL is of the form: orcidapi/{$orcidrequest}
+     *
+     * @see PKPPageRouter::route()
+     */
+    public function setupCallbackHandler($hookName, $params)
+    {
+        $page = $params[0];
+        if ($this->getEnabled() && $page == 'orcidapi') {
+            $this->import('pages/OrcidHandler');
+            define('HANDLER_CLASS', 'OrcidHandler');
+            return true;
+        }
+        return false;
+    }
+
 	/**
 	 * Check if there exist a valid orcid configuration section in the global config.inc.php of OJS.
 	 * @return boolean True, if the config file has api_url, client_id and client_secret set in an [orcid] section
@@ -277,11 +290,6 @@ class OrcidProfilePlugin extends GenericPlugin {
 			)
 		);
 
-		switch ($template) {
-			case 'frontend/pages/userRegister.tpl':
-				$templateMgr->registerFilter("output", array($this, 'registrationFilter'));
-				break;
-		}
 		return false;
 	}
 
@@ -302,25 +310,26 @@ class OrcidProfilePlugin extends GenericPlugin {
 	 * @return string
 	 */
 	function registrationFilter($output, $templateMgr) {
-		if (preg_match('/<form[^>]+id="register"[^>]+>/', $output, $matches, PREG_OFFSET_CAPTURE)) {
-			$match = $matches[0][0];
-			$offset = $matches[0][1];
-			# $request = Application::get()->getRequest();
-			# $context = $request->getContext();
-			# $contextId = ($context == null) ? 0 : $context->getId();
-			$targetOp = 'register';
-			$templateMgr->assign(array(
-				'targetOp' => $targetOp,
-				'orcidUrl' => $this->getOrcidUrl(),
-				'orcidOAuthUrl' => $this->buildOAuthUrl('orcidAuthorize', array('targetOp' => $targetOp)),
-				'orcidIcon' => $this->getIcon(),
-			));
+		$request = Application::get()->getRequest();
+		$context = $request->getContext();
+		if ($context != null) {
+			if (preg_match('/<form[^>]+id="register"[^>]+>/', $output, $matches, PREG_OFFSET_CAPTURE)) {
+				$match = $matches[0][0];
+				$offset = $matches[0][1];
+				$targetOp = 'register';
+				$templateMgr->assign(array(
+					'targetOp' => $targetOp,
+					'orcidUrl' => $this->getOrcidUrl(),
+					'orcidOAuthUrl' => $this->buildOAuthUrl('orcidAuthorize', array('targetOp' => $targetOp)),
+					'orcidIcon' => $this->getIcon(),
+				));
 
-			$newOutput = substr($output, 0, $offset + strlen($match));
-			$newOutput .= $templateMgr->fetch($this->getTemplateResource('orcidProfile.tpl'));
-			$newOutput .= substr($output, $offset + strlen($match));
-			$output = $newOutput;
-			$templateMgr->unregisterFilter('output', array($this, 'registrationFilter'));
+				$newOutput = substr($output, 0, $offset + strlen($match));
+				$newOutput .= $templateMgr->fetch($this->getTemplateResource('orcidProfile.tpl'));
+				$newOutput .= substr($output, $offset + strlen($match));
+				$output = $newOutput;
+				$templateMgr->unregisterFilter('output', array($this, 'registrationFilter'));
+			}
 		}
 		return $output;
 	}
@@ -366,6 +375,12 @@ class OrcidProfilePlugin extends GenericPlugin {
 		$redirectUrl = $request->getDispatcher()->url($request, ROUTE_PAGE, null, 'orcidapi',
 			$handlerMethod, null, $redirectParams);
 
+		// overwrite redirect base url if variable is provided in config.inc.php
+		$orcidRedirectBaseUrl = Config::getVar('orcidProfilePlugin', 'orcid_redirect_base_url');
+		if (!ValidatorFactory::make([$orcidRedirectBaseUrl], [['required','url']])->fails()) {
+			$redirectUrl = preg_replace("#^https{0,1}:\/\/(.*)\/#U", $orcidRedirectBaseUrl, $redirectUrl);
+		}
+
 		return $this->getOauthPath() . 'authorize?' . http_build_query(
 				array(
 					'client_id' => $this->getSetting($contextId, 'orcidClientId'),
@@ -385,6 +400,7 @@ class OrcidProfilePlugin extends GenericPlugin {
 		return file_exists($path) ? file_get_contents($path) : '';
 	}
 
+
 	/**
 	 * @return bool True if the ORCID Member API has been selected in this context.
 	 */
@@ -397,6 +413,7 @@ class OrcidProfilePlugin extends GenericPlugin {
 		}
 	}
 
+
 	/**
 	 * Return the OAUTH path (prod or sandbox) based on the current API configuration
 	 *
@@ -406,11 +423,11 @@ class OrcidProfilePlugin extends GenericPlugin {
 		return $this->getOrcidUrl() . 'oauth/';
 	}
 
-	public function isSandbox() {
-
-		$apiUrl = $this->getSetting($this->getCurrentContextId(), 'orcidProfileAPIPath');
-		return ($apiUrl == ORCID_API_URL_MEMBER_SANDBOX);
-
+	public function isSandbox()
+	{
+		$isSandBox = $this->getSetting($this->getCurrentContextId(), 'orcidProfileAPIPath') == ORCID_API_URL_MEMBER_SANDBOX ||
+			$this->getSetting($this->getCurrentContextId(), 'orcidProfileAPIPath') == ORCID_API_URL_PUBLIC_SANDBOX;
+		return $isSandBox;
 	}
 
 	/**
@@ -532,13 +549,13 @@ class OrcidProfilePlugin extends GenericPlugin {
 			$mail->setRecipients(array(array('name' => $author->getFullName(), 'email' => $author->getEmail())));
 
 			// Send the mail with parameters
-			$mail->sendWithParams(array(
+			$mail->sendWithParams([
 				'orcidAboutUrl' => $aboutUrl,
 				'authorOrcidUrl' => $oauthUrl,
-				'authorName' => $author->getFullName(),
-				'articleTitle' => $publication->getLocalizedTitle(), // Backwards compatibility only
-				'submissionTitle' => $publication->getLocalizedTitle(),
-			));
+				'authorName' => htmlspecialchars($author->getFullName()),
+				'articleTitle' => htmlspecialchars($publication->getLocalizedTitle()), // Backwards compatibility only
+				'submissionTitle' => htmlspecialchars($publication->getLocalizedTitle()),
+			]);
 
 			if ($updateAuthor) {
 				$authorDao = DAORegistry::getDAO('AuthorDAO');
@@ -591,8 +608,17 @@ class OrcidProfilePlugin extends GenericPlugin {
 		$form = $params[0];
 		$user = $form->user;
 
-		$form->readUserVars(array('orcid'));
+		$form->readUserVars(array('orcid','orcidAccessToken','orcidAccessScope','orcidRefreshToken','orcidAccessExpiresOn','orcidSandbox'));
 		$user->setOrcid($form->getData('orcid'));
+		$user->setData('orcidAccessToken', $form->getData('orcidAccessToken'));
+		$user->setData('orcidAccessScope', $form->getData('orcidAccessScope'));
+		$user->setData('orcidRefreshToken', $form->getData('orcidRefreshToken'));
+		if ($form->getData('orcidAccessExpiresOn')) {
+			$user->setData('orcidAccessExpiresOn', $form->getData('orcidAccessExpiresOn')->toDateTimeString);
+		}
+		$user->setData('orcidSandbox', true);
+
+
 		return false;
 	}
 
@@ -726,6 +752,7 @@ class OrcidProfilePlugin extends GenericPlugin {
 		return __('plugins.generic.orcidProfile.displayName');
 	}
 
+
 	function setEnabled($enabled) {
 		$contextId = $this->getCurrentContextId();
 		$request = Application::get()->getRequest();
@@ -756,7 +783,7 @@ class OrcidProfilePlugin extends GenericPlugin {
 
 		switch ($request->getUserVar('verb')) {
 			case 'settings':
-				$templateMgr = TemplateManager::getManager();
+				$templateMgr = TemplateManager::getManager($request);
 				$templateMgr->registerPlugin('function', 'plugin_url', array($this, 'smartyPluginUrl'));
 				$apiOptions = [
 					ORCID_API_URL_PUBLIC => 'plugins.generic.orcidProfile.manager.settings.orcidProfileAPIPath.public',
@@ -822,6 +849,7 @@ class OrcidProfilePlugin extends GenericPlugin {
 		switch ($newPublication->getData('status')) {
 			case STATUS_PUBLISHED:
 			case STATUS_SCHEDULED:
+				$this->logInfo("Expected publication status (5 or 3):  ".$newPublication->getData('status'));
 				$this->publishAuthorWorkToOrcid($newPublication, $request);
 				break;
 		}
@@ -869,6 +897,7 @@ class OrcidProfilePlugin extends GenericPlugin {
 							[
 								'headers' => $headers,
 								'json' => $orcidReview,
+								'allow_redirects' => ['strict' => true],
 							]
 						);
 					} catch (ClientException $exception) {
@@ -918,6 +947,8 @@ class OrcidProfilePlugin extends GenericPlugin {
 	 *
 	 **/
 	public function publishAuthorWorkToOrcid($publication, $request) {
+		$this::logInfo("Publishing  publication with id ".$publication->getData('id')  );
+		$templateMgr = TemplateManager::getManager($request);
 		$context = $request->getContext();
 		$contextId = $context->getId();
 		$publicationId = $publication->getId();
@@ -925,6 +956,7 @@ class OrcidProfilePlugin extends GenericPlugin {
 
 		if (!$this->isMemberApiEnabled($contextId)) {
 			// Sending to ORCID only works with the member API
+			$this->logInfo("Member API disabled");
 			return false;
 		}
 
@@ -963,6 +995,7 @@ class OrcidProfilePlugin extends GenericPlugin {
 
 		$requestsSuccess = [];
 		foreach ($authorsWithOrcid as $orcid => $author) {
+			$this->logInfo("Publishing author work ". $author->getData('orcid'));
 			$uri = $this->getSetting($contextId, 'orcidProfileAPIPath') . ORCID_API_VERSION_URL . $orcid . '/' . ORCID_WORK_URL;
 			$method = "POST";
 
@@ -994,11 +1027,14 @@ class OrcidProfilePlugin extends GenericPlugin {
 					[
 						'headers' => $headers,
 						'json' => $orcidWork,
+						'allow_redirects' => ['strict' => true],
 					]
 				);
+
 			} catch (ClientException $exception) {
 				$reason = $exception->getResponse()->getBody(false);
 				$this->logInfo("Publication fail: $reason");
+				$templateMgr->assign('orcidAPIError', $reason);
 				return new JSONMessage(false);
 			}
 			$httpstatus = $response->getStatusCode();
@@ -1060,6 +1096,17 @@ class OrcidProfilePlugin extends GenericPlugin {
 			return $requestsSuccess;
 		}
 	}
+	/**
+	 * Encode DOI according to ANSI/NISO Z39.84-2005, Appendix E.
+	 * @param $pubId string
+	 * @return string
+	 */
+	function _doiURLEncode($pubId) {
+		$search = array ('%', '"', '#', ' ', '<', '>', '{');
+		$replace = array ('%25', '%22', '%23', '%20', '%3c', '%3e', '%7b');
+		$pubId = str_replace($search, $replace, $pubId);
+		return $pubId;
+	}
 
 	public function buildOrcidReview($submission, $review, $request, $issue = null) {
 		$publicationUrl = $request->getDispatcher()->url($request, ROUTE_PAGE, null, 'article', 'view', $submission->getId());
@@ -1109,7 +1156,7 @@ class OrcidProfilePlugin extends GenericPlugin {
 				$orcidReview['review-url'] = ['value' => $publicationUrl];
 				$orcidReview['subject-type'] = 'journal-article';
 				$orcidReview['subject-name']= [
-					'title' => ['value' => $submission->getCurrentPublication()->getLocalizedData('title') ?? '']
+					'title' => ['value' => $submission->getCurrentPublication()->getLocalizedTitle() ?? '']
 				];
 
 
@@ -1119,7 +1166,7 @@ class OrcidProfilePlugin extends GenericPlugin {
 						'external-id-type' => 'doi',
 						'external-id-value' => $submission->getData('pub-id::doi'),
 						'external-id-url' => [
-							'value' => 'https://doi.org/' . $submission->getData('pub-id::doi')
+							'value' =>  $this->getResolvingURL($submission->getData('pub-id::doi')),
 						],
 						'external-id-relationship' => 'self'
 
@@ -1133,7 +1180,7 @@ class OrcidProfilePlugin extends GenericPlugin {
 			foreach ($supportedSubmissionLocales as $defaultLanguage) {
 				if ($defaultLanguage !== $publicationLocale) {
 					$iso2LanguageCode = substr($defaultLanguage, 0, 2);
-					$defaultTitle = $submission->getLocalizedData($iso2LanguageCode);
+					$defaultTitle = $submission->getLocalizedTitle($iso2LanguageCode);
 					if (strlen($defaultTitle) > 0 && !$translatedTitleAvailable) {
 						$orcidReview['subject-name']['translated-title'] = ['value' => $defaultTitle, 'language-code' => $iso2LanguageCode];
 						$translatedTitleAvailable = true;
@@ -1169,6 +1216,15 @@ class OrcidProfilePlugin extends GenericPlugin {
 		self::writeLog($message, 'ERROR');
 	}
 
+	/**
+	 * creates the DOI URL
+	 * @param $pubId
+	 * @return string
+	 */
+	function getResolvingURL($pubId) {
+		return 'https://doi.org/'.$this->_doiURLEncode($pubId);
+	}
+
 	/**
 	 * Build an associative array with submission meta data, which can be encoded to a valid ORCID work JSON structure.
 	 *
@@ -1191,12 +1247,15 @@ class OrcidProfilePlugin extends GenericPlugin {
 		$publicationLocale = ($publication->getData('locale')) ? $publication->getData('locale') : 'en_US';
 		$supportedSubmissionLocales = $context->getSupportedSubmissionLocales();
 
-		$publicationUrl = $request->getDispatcher()->url($request, ROUTE_PAGE, null, 'article', 'view', $submission->getId());
+		$articleUrl = $request->getDispatcher()->url($request, ROUTE_PAGE, null, 'article', 'view', $submission->getId());
+
+		$pubId = $publication->getStoredPubId($this->getPubIdType());
+		$publicationUrl = $pubId ? $this->getResolvingURL($pubId) : $articleUrl;
 
 		$orcidWork = [
 			'title' => [
 				'title' => [
-					'value' => $publication->getLocalizedData('title', $publicationLocale) ?? ''
+					'value' => $publication->getLocalizedTitle() ?? ''
 				],
 				'subtitle' => [
 					'value' => $publication->getLocalizedData('subtitle', $publicationLocale) ?? ''
@@ -1259,6 +1318,14 @@ class OrcidProfilePlugin extends GenericPlugin {
 		error_log("$fineStamp $level $message\n", 3, self::logFilePath());
 	}
 
+	/**
+	 * return main pubid type
+	 * @return string
+	 */
+	private  function getPubIdType (){
+		return 'doi';
+	}
+
 	/**
 	 * Build the external identifiers ORCID JSON structure from article, journal and issue meta data.
 	 *
@@ -1267,7 +1334,7 @@ class OrcidProfilePlugin extends GenericPlugin {
 	 * @param Submission $submission The Article object for which the external identifiers should be build.
 	 * @param Publication $publication The Article object for which the external identifiers should be build.
 	 * @param Journal $context Context the Submission is part of.
-	 * @param Issue $issue The Issue object the Article object belongs to.
+	 * @param Issue|null $issue The Issue object the Article object belongs to.
 	 * @return array            An associative array corresponding to ORCID external-id JSON.
 	 */
 	protected function buildOrcidExternalIds($submission, $publication, $context, $issue, $articleUrl) {
@@ -1286,7 +1353,7 @@ class OrcidProfilePlugin extends GenericPlugin {
 				$pubIdType = $plugin->getPubIdType();
 
 				# Add article ids
-				$pubId = $publication->getData($pubIdType);
+				$pubId = $publication->getStoredPubId($pubIdType);
 
 				if ($pubId) {
 					$externalIds[] = [
@@ -1302,16 +1369,18 @@ class OrcidProfilePlugin extends GenericPlugin {
 				}
 
 				# Add issue ids if they exist
-				$pubId = $issue->getStoredPubId($pubIdType);
-				if ($pubId) {
-					$externalIds[] = [
-						'external-id-type' => self::PUBID_TO_ORCID_EXT_ID[$pubIdType],
-						'external-id-value' => $pubId,
-						'external-id-url' => [
-							'value' => $plugin->getResolvingURL($contextId, $pubId)
-						],
-						'external-id-relationship' => 'part-of'
-					];
+				if ($issue !== null) {
+					$pubId = $issue->getStoredPubId($pubIdType);
+					if ($pubId) {
+						$externalIds[] = [
+							'external-id-type' => self::PUBID_TO_ORCID_EXT_ID[$pubIdType],
+							'external-id-value' => $pubId,
+							'external-id-url' => [
+								'value' => $plugin->getResolvingURL($contextId, $pubId)
+							],
+							'external-id-relationship' => 'part-of'
+						];
+					}
 				}
 			}
 		} else {
@@ -1432,5 +1501,70 @@ class OrcidProfilePlugin extends GenericPlugin {
 	public function setCurrentContextId($contextId) {
 		$this->currentContextId = $contextId;
 	}
+
+	/**
+	 * handleEditorAction handles promoting a submission to copyediting.
+	 *
+	 * @param $hookName string Name the hook was registered with
+	 * @param $args array Hook arguments, &$submission, &$editorDecision, &$result, &$recommendation.
+	 *
+	 * @see EditorAction::recordDecision() The function calling the hook.
+	 */
+	public function handleEditorAction($hookName, $args)
+	{
+		$submission = $args[0];
+		/** @var Submission $submission */
+		$decision = $args[1];
+
+		if ($decision['decision'] == SUBMISSION_EDITOR_DECISION_ACCEPT) {
+			$publication = $submission->getCurrentPublication();
+
+			if (isset($publication)) {
+				$authorDao = DAORegistry::getDAO('AuthorDAO');
+				/** @var AuthorDAO $authorDao */
+
+				$authors = $authorDao->getByPublicationId($submission->getCurrentPublication()->getId());
+
+				foreach ($authors as $author) {
+					$orcidAccessExpiresOn = Carbon\Carbon::parse($author->getData('orcidAccessExpiresOn'));
+					if ($author->getData('orcidAccessToken') == null || $orcidAccessExpiresOn->isPast()) {
+						$this->sendAuthorMail($author, true);
+					}
+				}
+			}
+
+		}
+	}
+
+	/**
+	 * Pre-publication checks
+	 * @param $hookName
+	 * @param $args
+	 * @return false
+	 */
+	function validate($hookName, $args)
+	{
+		$errors =& $args[0];
+		$publication = $args[1];
+		$orcidIds = [];
+		foreach ($publication->getData('authors') as $author) {
+			$authorOrcid = $author->getData('orcid');
+			if ($authorOrcid and in_array($authorOrcid, $orcidIds)) {
+				$errors['hasDuplicateOrcids'] = __('plugins.generic.orcidProfile.verify.duplicateOrcidAuthor');
+			} elseif ($authorOrcid && $this->isMemberApiEnabled($this->getCurrentContextId()) && !$author->getData('orcidAccessToken')) {
+				$errors['hasUnauthenticatedOrcid'] = __('plugins.generic.orcidProfile.verify.hasUnauthenticatedOrcid');
+			} else {
+				$orcidIds [] = $authorOrcid;
+			}
+		}
+
+		return false;
+	}
+
+	function getCurrentContextId() {
+		$context = Application::get()->getRequest()->getContext();
+		return is_null($context) ? 0 : $context->getId();
+	}
+
 }
 
