@@ -43,7 +43,7 @@ class OAIMetadataFormatPlugin_MARC21 extends OAIMetadataFormatPlugin {
 	}
 
 	static function getSchema() {
-		return 'http://www.loc.gov/standards/marcxml/schema/MARC21slim.xsd';
+		return 'https://www.loc.gov/standards/marcxml/schema/MARC21slim.xsd';
 	}
 
 	static function getNamespace() {
